Index: audio.c
===================================================================
RCS file: /usr/local/cvsroot/win32-tools/oggdrop/audio.c,v
retrieving revision 1.1
diff -u -r1.1 audio.c
--- audio.c	2000/11/07 09:01:39	1.1
+++ audio.c	2001/08/01 20:19:11
@@ -68,22 +68,25 @@
 
 int wav_open(FILE *in, oe_enc_opt *opt)
 {
-	unsigned char buf[16];
+  unsigned char hdrbuf[12];
+	unsigned char *buf;
 	unsigned int len;
 	wav_fmt format;
 	wavfile *wav = malloc(sizeof(wavfile));
 
-	int ret = fread(buf, 1, 12, in);
+	int ret = fread(hdrbuf, 1, 12, in);
 	if(ret < 12)
 		return 0;
 
-	if(memcmp(buf, "RIFF", 4))
+	if(memcmp(hdrbuf, "RIFF", 4))
 		return 0;
 
-	len = READ_U32(buf+4); /* We don't actually use this */
-	if(memcmp(buf+8, "WAVE",4))
+	len = READ_U32(hdrbuf+4); 
+	if(memcmp(hdrbuf+8, "WAVE",4))
 		return 0; /* Not wave file */
 
+	buf = malloc(len);
+
 	/* Ok. At this point, we know we have a WAV file. Now we have to detect
 	 * whether we support the subtype, and we have to find the actual data
 	 */
@@ -91,24 +94,56 @@
 	if(!find_chunk(in, "fmt ", &len))
 		return 0; /* EOF */
 
-	if(len!=16) 
+	if(len<16) 
 	{
-		fprintf(stderr, "Warning: Unrecognised format chunk in WAV header\n");
+		free(buf);
+		fprintf(stderr, "Error: Truncated format chunk in WAV header\n");
 		return 0; /* Weird format chunk */
 	}
 
-	if(fread(buf,1,16,in) < 16)
+	if(fread(buf,1,len,in) < len)
 	{
-		fprintf(stderr, "Warning: Unexpected EOF in reading WAV header\n");
+		free(buf);
+		fprintf(stderr, "Error: Unexpected EOF in reading WAV header\n");
 		return 0;
 	}
 
 	format.format =      READ_U16(buf); 
+
+  /* Temporary hack, until we decide were to put this defined constant. */
+#ifndef WAVE_FORMAT_PCM
+# define WAVE_FORMAT_PCM 0x0001
+#endif
+
+	if(format.format != WAVE_FORMAT_PCM)
+	{
+		free(buf);
+		(void)fprintf(stderr, 
+			"Error: WAVE format: %#02.02x not supported.\n", format.format);
+		return 0;
+	}
+	else if(len > 18)
+	{
+#ifdef STRICT_FORMAT_POLICY
+		free(buf);
+		(void)fprintf(stderr,
+			"Error: WAVE PCM with bad format size: %d\n", len);
+		return 0;
+#else
+		(void)fprintf(stderr,
+			"Warning: WAVE PCM with bad format size: %d\n", len);
+		(void)fprintf(stderr,
+			"         conversion may fail.\n", len);
+#endif
+	}
+
 	format.channels =    READ_U16(buf+2); 
 	format.samplerate =  READ_U32(buf+4);
 	format.bytespersec = READ_U32(buf+8);
 	format.align =       READ_U16(buf+12);
 	format.samplesize =  READ_U16(buf+14);
+
+	free(buf);
 
 	if(!find_chunk(in, "data", &len))
 		return 0; /* EOF */